MTCNN Model Weights
===================

These were converted by the `faceie-convert-mtcnn-weights` script from the
format in which they were published along with
[facenet-pytorch](https://github.com/timesler/facenet-pytorch) (MIT License).
These were in turn ported from the Tensor Flow based
[davidsandberg/facenet](https://github.com/davidsandberg/facenet) (also MIT
License).
